globals
 [
   price.pcs           ; purchase price P1
   price.wsl           ; wholesale price P2
   price.ctr           ; contract price Pr
   price.deal          ; price of makeing deal
   num-product         ; product number per a farmer
   cost.low            ; cost of producing goods with low quality Cl
   cost.high           ; cost of producing goods with high quality Cs
   cost.c.high         ; cost of producing goods with high quality by contracted farmer C's
   cost.ivg            ; cost of investigating by contracted seller Ci
   rho                 ; stochastic number ρ
   delta               ; extra ratio between wholesale price and market price δ
   expect.n            ; non-contracted farmer expect value between safe and unsafe produce
   expect.c            ; contracted farmer expect value between safe and unsafe produce
   expect              ; expect value
   honesty.p           ; positive factor of honesty d+
   honesty.n           ; negative factor of honesty d-
   honesty.m           ; minimal honesty minimal_Honesty
   mean.honesty        ; average honesty of farmers
   mean.f.c            ; average profit of contracted farmer
   mean.f.n            ; average profit of non-contracted farmer
   mean.r.s.c          ; average profit rate of contracted seller
   mean.r.s.n          ; average profit rate of non-contracted seller
   sample.f.f.m        ; amount of unsafe contracted farmer who is found by sampled seller
   threshold.f.a1      ; active factor of farmer's threshold s1+
   threshold.f.a2      ; active factor of farmer's threshold s2+
   threshold.f.i1      ; inactive factor of farmer's threshold s1-
   threshold.f.i2      ; inactive factor of farmer's threshold s2-
   inspect-seller      ; the number of seller inspected
   inspect-farmer      ; the number of farmer inspected
   fine.s              ; seller's fine per unit
   ratio.c.p           ; contract production ratio
 ]

breed [ farmers farmer ]
breed [ sellers seller ]
breed [ govs gov ]
breed [ vegs veg ]
undirected-link-breed [ contracts contract ]  ; link farmer and seller
undirected-link-breed [ products product ]    ; link farmer and veg
undirected-link-breed [ goods good ]          ; link seller and veg
undirected-link-breed [ infs inf ]            ; link gov and farmer
undirected-link-breed [ inses inse ]          ; link gov and seller

farmers-own
 [
   contract.f         ; 1 contracted farmer
   wealth.f           ; wealth of farmer
   honesty            ; honesty of farmer
   farmer.m           ; farmer is matched with seller
   fake               ; 1 farmer unsafe produce, 0 farmer safe produce
   sample.f           ; 1 farmer is sampled by gov
   sample.f.f         ; 1 unsafe contracted farmer is found by sampled seller
   profit.f           ; profit of farmer
   profit.r.f         ; profit rate of farmer
   threshold.f        ; transforming threshold value between two kinds of farmers
   transform.f        ; 1 farmer has transformed
   transform.f.c      ; 1 non-contracted farmer want to transform contracted farmer
 ]

sellers-own
 [
   contract.s         ; contracted seller
   num-match          ; the number of farmers match with one seller
   wealth.s           ; wealth of seller
   sample.s           ; 1 seller is sampled by gov
   sample.s.f         ; 1 sampled seller is found to fake
   profit.s           ; profit of seller
   profit.r.s         ; profit rate of seller
   threshold.s        ; transforming threshold value between two kinds of sellers
   transform.s.c      ; 1 non-contracted seller want to transform contracted seller
   transform.s.n      ; 1 contracted seller want to transform non-contracted seller
 ]

govs-own
 [
   qualification.r.g  ; the government's goal on the qualified rate of product
   budget.g           ; budget constraint on government's inspection
 ]

vegs-own
 [
   quality            ; product's quality
 ]

;;;;;;;;;;;;;;;;;;;;;;;;
;;; Setup procedures ;;;
;;;;;;;;;;;;;;;;;;;;;;;;

to setup
  ca
  setup-initialize
  set-default-shape farmers "person farmer"
  set-default-shape sellers "house"
  ask patches [set pcolor green]
  setup-farmers
  setup-sellers
  setup-match
  setup-govs
  set inspect-seller ceiling (inspect-rate.s * num-seller)
  set inspect-farmer ceiling (inspect-rate.f * num-farmer)

  let a (cost.high - cost.low - (fine-farmer * inspect-farmer / num-farmer))      ; setting k1
  let b (cost.high - cost.low)
  set expect.n a / b

  reset-ticks

end

;;; Procedures in setup

to setup-initialize
  set num-product 50
  set cost.low 1
  set cost.high 1.5
  set cost.c.high 1.4
  set cost.ivg 0.5
  set honesty.p 0.1
  set honesty.n 0.11
  set honesty.m 0.1
  set delta 0.5
  set price.deal cost.c.high
  set price.ctr lambda * cost.c.high + (1 - lambda) * price.deal
  set threshold.f.a1 0.1
  set threshold.f.a2 0.05
  set threshold.f.i1 0.15
  set threshold.f.i2 0.2
end

to setup-farmers
  create-farmers num-farmer
  [
    setxy random-xcor random-ycor
    set color yellow
    set size 1.2
    set contract.f 0
    set farmer.m 0
    set honesty 0.01
    set fake 0
    set wealth.f 100
    set threshold.f 0.1
    set transform.f 0
    set transform.f.c 0
  ]
end

to setup-sellers
  create-sellers num-seller
  [
    setxy random-xcor random-ycor
    set color yellow
    set size 2.2
    set contract.s 0
    set wealth.s 1000
    set threshold.s 0.2
    set transform.s.c 0
    set transform.s.n 0
  ]
end

to setup-match
  if contractual?      ; switch on
  [
    ask one-of sellers
    [
      set color blue
      set contract.s 1
    ]
    ask n-of (round (num-farmer / num-seller)) farmers         ; generate contracted seller
    [
      create-contract-with min-one-of (sellers with [ contract.s = 1 ]) [ distance myself ]
      [ set color red ]
      set contract.f 1
    ]
  ]
  ask farmers with [ contract.f = 0 ]
  [
    create-contract-with min-one-of (sellers with [ contract.s = 0 ]) [ distance myself ]
  ]
  ask sellers
  [
    set num-match (count contract-neighbors)
  ]
end

to setup-govs
  set-default-shape govs "van side"
  create-govs 2
  [
    set size 2.7
    set color red
    move-to one-of patches with [ pycor > 0 and pycor < 31 and pxcor > 0 and pxcor < 31 ]
  ]
end


;;;;;;;;;;;;;;;;;;;;;;;;
;;;  Go procedures   ;;;
;;;;;;;;;;;;;;;;;;;;;;;;

to go

  ;; generate purchase price P1
  set price.pcs lambda * cost.high + (1 - lambda) * cost.low + ( random-normal 0.35 0.35 )

  if (ticks = 100)
  [ stop ]
  ;if (count farmers with [ contract.f = 0 ] = 0)
 ; [ stop ]


  ask farmers with [ contract.f = 0 ]
  [
    if any? contract-neighbors
    [
      set expect expect.n
      do-produce
     ]
  ]

  ask farmers with [ contract.f = 1 ]
  [
    if any? contract-neighbors
    [
      define-expect.c
      do-produce
    ]
  ]

  ;; calculate the qualified rate of products
  do-qualified-rate

  ;; inspect farmers
  do-monitor-farmer

  ;; inspect sellers and vegetables
  do-monitor-seller

  ask farmers
  [
    update-honesty
    update-wealth.farmer
  ]

  set mean.honesty mean [ honesty ] of farmers

  ;; contracted farmer's transformation decision
  if any? farmers with [ contract.f = 0 ]
  [
    ask farmers with [ contract.f = 1 ]
    [
      do-compare-profit.farmer.c
    ]
  ]

  ;; non-contracted farmer's transformation decision
  if any? farmers with [ contract.f = 1 ]
  [
    ask farmers with [ contract.f = 0 and transform.f = 0 ]
    [
      do-compare-profit.farmer.n
    ]
  ]

  ;; transaction price of contracted farmer in the last term P1'(t-1)
  update-price.deal

  ;; generate contract price Pr
  set price.ctr lambda * cost.c.high + (1 - lambda) * price.deal

  ask sellers
  [
    update-wealth.seller
  ]

  ;; non-contracted seller's transformation decision
  if any? sellers with [ contract.s = 1 ]
  [
    ask sellers with [ contract.s = 0 ]
    [
      do-compare-profit.seller.n
    ]
  ]

  ;; contracted seller's transformation decision
  if any? sellers with [ contract.s = 0 ]
  [
    ask sellers with [ contract.s = 1 ]
    [
      do-compare-profit.seller.c
    ]
  ]

  do-transform-seller

  ask vegs [ die ]

  ask farmers with [contract.f = 0]
  [
    ask my-links [die]
  ]

  ;; farmer match with seller
  do-match

  ;; calculate contract production ratio
  do-contract-production-ratio

  ;; restore agent's relevant variables
  do-restore

  do-plots1

  do-plots2

  tick

end

;;; Procedures in go

to define-expect.c      ; setting k2
  let c (cost.c.high - cost.low - fine-farmer * inspect-farmer / num-farmer)
  let d (fine-deposit * inspect-seller * num-inspect-veg)
  let f (num-seller * num-product * [ num-match ] of (one-of contract-neighbors))
  let h (fine-farmer + fine-deposit) * inspect-seller * inspect-farmer * num-inspect-veg
  let i (num-seller * num-product *  [ num-match ] of (one-of contract-neighbors) * num-farmer)
  let j (cost.c.high - cost.low)
  set expect.c (c - d / f + h / i) / j
  set expect expect.c
end

to do-produce
  set rho random-float 1
  let expect.difference lambda * expect + (1 - lambda) * rho    ; expected profit difference
  set price.wsl price.pcs * (1 + delta)                         ; generate wholesale price P2
  let sellerID [ who ] of one-of contract-neighbors
  ifelse expect.difference > honesty
  [
    set fake 1
    hatch-vegs num-product
    [
      set quality 0
      set hidden? true
      create-product-with myself           ; link vegetables with farmers
      create-good-with (seller sellerID)
     ]
   ]
   [
     set fake 0
     hatch-vegs num-product

     [
       set quality 1
       set hidden? true
       create-product-with myself
       create-good-with (seller sellerID)
     ]
   ]
end

to do-qualified-rate
  ask govs
  [
   let qr count vegs with [ quality = 1 ]
   let tv count vegs
   set qualification.r.g (qr / tv )
  ]
end

to do-monitor-farmer                               ; inspect farmers, sellers and vegetables
  ask n-of inspect-farmer farmers
  [
    if any? contract-neighbors
    [
      set sample.f 1
      set color red
      ask farmers in-radius 3
      [
        set color red
      ]
    ]
  ]
end

to do-monitor-seller                                 ; inspect sellers and vegetables
  ask n-of inspect-seller sellers
  [
    if any? contract-neighbors
    [
      set sample.s 1
      set color red
      ifelse contract.s = 1
      [
        ask n-of num-inspect-veg good-neighbors       ; inspect contracted seller's vegetables
        [
          if quality = 0
          [
            ask good-neighbors
            [ set sample.s.f 1 ]
            ask product-neighbors
            [ set color red  set sample.f.f 1 ]
          ]
        ]
        set sample.f.f.m (count contract-neighbors with [ sample.f.f = 1 ])
      ]
      [
        ask n-of num-inspect-veg good-neighbors       ; inspect non-contracted seller's vegetables
        [
          if quality = 0
          [
            ask good-neighbors
            [
              set sample.s.f 1
            ]
          ]
        ]
      ]
    ]
  ]
end

to update-honesty           ; to change honesty of farmers
  ifelse color = red
  [ set honesty (1 - honesty.n) * honesty + honesty.n ]
  [ set honesty (1 - honesty.p) * honesty + honesty.p * honesty.m ]
end

to update-wealth.farmer     ; to change wealth of farmers
   update-profit.f.non
   update-profit.f.con
   set wealth.f profit.f + wealth.f
end

to update-profit.f.non      ; non-contracted farmer's profit
  ifelse any? contract-neighbors
  [
    if contract.f = 0
    [
      ifelse fake = 0        ; producing safe products
      [ set profit.f num-product * (price.pcs - cost.high) ]
      [
        ifelse sample.f = 1
        [ set profit.f num-product * (price.pcs - cost.low - fine-farmer) ]
        [ set profit.f num-product * (price.pcs - cost.low) ]
      ]
    ]
  ]
  [
    set profit.f 0
  ]

end

to update-profit.f.con     ; contracted farmer's profit
  ifelse any? contract-neighbors
  [
    if contract.f = 1
    [
      ifelse price.pcs > price.ctr      ; P1 > Pr
      [
        ifelse fake = 0
        [ set profit.f num-product * (price.pcs - cost.c.high) ]
        [
          ifelse sample.f = 1
          [
            ifelse sample.f.f = 1
            [ set profit.f num-product * (price.pcs - cost.low - fine-farmer - fine-deposit) ]
            [ set profit.f num-product * (price.pcs - cost.low - fine-farmer) ]
          ]
          [
            ifelse sample.f.f = 1
            [ set profit.f num-product * (price.pcs - cost.low - fine-deposit) ]
            [ set profit.f num-product * (price.pcs - cost.low) ]
          ]
         ]
       ]
       [                                 ; P1 <= Pr
         ifelse fake = 0
         [ set profit.f num-product * (price.ctr - cost.c.high) ]
         [
           ifelse sample.f = 1
           [
             ifelse sample.f.f = 1
             [ set profit.f num-product * (price.ctr - cost.low - fine-farmer - fine-deposit) ]
             [ set profit.f num-product * (price.ctr - cost.low - fine-farmer) ]
           ]
           [
             ifelse sample.f.f = 1
             [ set profit.f num-product * (price.ctr - cost.low - fine-deposit) ]
             [ set profit.f num-product * (price.ctr - cost.low) ]
           ]
         ]
       ]
    ]
  ]
  [
    set profit.f 0
  ]
end

to update-price.deal
  ifelse price.ctr < price.pcs
  [ set price.deal price.pcs ]
  [ set price.deal price.ctr ]
end

to do-compare-profit.farmer.c     ; contracted farmer's transformation decision
  set rho random-float 1
  if any? (farmers in-radius 3) with [ contract.f = 0 ]
  [
    set mean.f.n mean [ profit.f ] of ((farmers in-radius 3) with [ contract.f = 0 ])
  ]
  ifelse profit.f < mean.f.n
  [
    if mean.f.n = 0
    [
      set mean.f.n 0.001
    ]
    let ψ1 (abs (lambda * (mean.f.n - profit.f) / mean.f.n) + (1 - lambda) * rho)
    ifelse ψ1 > threshold.f
    [

      ask my-links [ die ]
      set contract.f 0
      set transform.f 1
      set farmer.m 0
      set threshold.f 0.1
    ]
    [
      ifelse sample.f.f = 1
      [ set threshold.f (1 - threshold.f.i2) * threshold.f ]
      [ set threshold.f (1 - threshold.f.i1) * threshold.f ]
    ]
  ]
  [
    ifelse sample.f.f = 1
    [ set threshold.f (1 - threshold.f.a2) * threshold.f + threshold.f.a2 ]
    [ set threshold.f (1 - threshold.f.a1) * threshold.f + threshold.f.a1 ]
  ]
end

to do-compare-profit.farmer.n     ; non-contracted farmer's transformation decision
  set rho random-float 1
  ask my-links [ die ]
  set farmer.m 0
  if any? (farmers in-radius 3) with [ contract.f = 1 ]
  [
    set mean.f.c mean [ profit.f ] of (farmers in-radius 3) with [ contract.f = 1 ]
  ]
  ifelse profit.f < mean.f.c
  [
    if mean.f.c = 0
    [
      set mean.f.c 0.001
    ]
    let ψ2 (abs (lambda * (mean.f.c - profit.f) / mean.f.c) + (1 - lambda) * rho)
    ifelse ψ2 > threshold.f
    [ set transform.f.c 1 ]
    [ set threshold.f (1 - threshold.f.i1) * threshold.f ]
   ]
   [
     set threshold.f (1 - threshold.f.a1) * threshold.f + threshold.f.a1
   ]
end

to update-wealth.seller           ; to change wealth of seller
  ifelse contract.s = 0
  [
    update-profit.s.non
  ]
  [
    update-profit.s.con
  ]
   set wealth.s profit.s + wealth.s
end

to update-profit.s.non            ; non-contracted seller's profit
  ifelse num-match > 0
  [
    ifelse sample.s.f = 1
    [ set fine.s fine-seller ]
    [ set fine.s 0]
    set profit.s num-product * num-match * (price.wsl - price.pcs - fine.s)
    set profit.r.s profit.s / (num-product * num-match * price.wsl)
  ]
  [
    set profit.s 0
    set profit.r.s 0
  ]
end

to update-profit.s.con            ; contracted seller's profit
  ifelse num-match > 0
  [
    if price.pcs > price.ctr      ; P1 > Pr
    [
      ifelse sample.s.f = 1
      [
        let s1 num-product * num-match * (price.wsl - price.pcs - fine-seller)
        set profit.s (s1 - cost.ivg * num-match + num-product * sample.f.f.m * fine-deposit)
        set profit.r.s profit.s / (num-product * num-match * price.wsl)
      ]
      [
        set profit.s num-product * num-match * (price.wsl - price.pcs)
        set profit.r.s profit.s / (num-product * num-match * price.wsl)
      ]
    ]
    if price.pcs < price.ctr      ; P1 < Pr
    [
      ifelse sample.s.f = 1
      [
        let s2 num-product * num-match * (price.wsl - price.ctr - fine-seller)
        set profit.s (s2 - cost.ivg * num-match + num-product * sample.f.f.m * fine-deposit)
        set profit.r.s profit.s / (num-product * num-match * price.wsl)
      ]
      [
        set profit.s num-product * num-match * (price.wsl - price.ctr)
        set profit.r.s profit.s / (num-product * num-match * price.wsl)
      ]
    ]
  ]
  [
    set profit.s 0
    set profit.r.s 0
  ]
end

to do-compare-profit.seller.n       ; non-contracted seller's transformation decision
  set rho random-float 1
  ask my-links [ die ]
  if any? sellers with [ contract.s = 1 ]
  [
    set mean.r.s.c mean [ profit.r.s ] of sellers with [ contract.s = 1 ]
  ]
  if profit.r.s < mean.r.s.c
  [
    if mean.r.s.c = 0
    [
      set mean.r.s.c 0.001
    ]
    let u2 (abs (lambda * (mean.r.s.c - profit.r.s) / mean.r.s.c) + (1 - lambda) * rho)
    if u2 > threshold.s
    [ set transform.s.c 1 ]
  ]
end

to do-compare-profit.seller.c       ; contracted seller's transformation decision
  set rho random-float 1
  if any? sellers with [ contract.s = 0 ]
  [
    set mean.r.s.n mean [ profit.r.s ] of sellers with [ contract.s = 0 ]
    if profit.r.s < mean.r.s.n
    [
      if mean.r.s.n = 0
      [
        set mean.r.s.n 0.001
      ]
      let u1 (abs (lambda * (mean.r.s.n - profit.r.s) / mean.r.s.n) + (1 - lambda) * rho)
      if u1 > threshold.s
      [ set transform.s.n 1 ]
    ]
  ]
end

to do-transform-seller
  if (count sellers with [ contract.s = 1 ] > 0) and (count sellers with [ contract.s = 0 ] > 0)
  [
    if any? sellers with [ transform.s.c = 1 ]
    [
      ask one-of sellers with [ transform.s.c = 1 ]      ; choose one of non-contracted seller who want to transform
      [
        ask other sellers with [ transform.s.c = 1 ]
        [ set transform.s.c  0 ]
      ]
    ]
    if any? sellers with [ transform.s.n = 1 ]
    [
      ask one-of sellers with [ transform.s.n = 1 ]
      [
        set contract.s 0
        ask contract-neighbors
        [
          set contract.f 0
          set farmer.m 0
        ]
        ask my-links [ die ]
      ]
    ]
    ask sellers with [ contract.s = 1 ]
    [
      if not any? contract-neighbors
      [
        set contract.s 0
      ]
    ]
  ]
end


to do-match
  let nn (count farmers with [ transform.f.c = 1 ])
  if nn > 0
  [
   if any? sellers with [ contract.s = 1 or transform.s.c = 1 ]
   [
     ask farmers with [ transform.f.c = 1 ]
     [
       create-contract-with min-one-of (sellers with [ contract.s = 1 or transform.s.c = 1 ]) [ distance myself ]
       [ set color red ]
       set contract.f 1
       set transform.f.c 0
       set farmer.m 1
       set threshold.f 0.1
       ask contract-neighbors
       [
         set contract.s 1
         set color green
          set transform.s.c 0
       ]
     ]
   ]
  ]
  let fn count farmers with [ contract.f = 0 ]
  if fn > 0
  [
    if (count sellers with [ contract.s = 0 ] > 0)
    [
      ask farmers with [ contract.f = 0 ]
      [
        create-contract-with min-one-of (sellers with [ contract.s = 0 ]) [ distance myself ]
      ]
    ]
  ]
end

to do-contract-production-ratio
  let cf count farmers with [ contract.f = 1 ]
  let fs count farmers
  set ratio.c.p (cf / fs )
end


to do-restore
  ask farmers
  [
    set color yellow
    set sample.f 0
    set sample.f.f 0
    set transform.f.c 0
    set transform.f 0
    set farmer.m 0
  ]
  ask sellers
  [
    set sample.s 0
    set sample.s.f 0
    set transform.s.c 0
    set transform.s.n 0
    set num-match (count contract-neighbors)
  ]
  ask sellers with [ contract.s = 0 ] [ set color yellow ]
  ask sellers with [ contract.s = 1 ] [ set color blue ]
end


to do-plots1
  set-current-plot "Qualified Rate"
  set-current-plot-pen "qualified-rate"
  plot [qualification.r.g] of one-of govs
end

to do-plots2
  set-current-plot "Average Honesty"
  set-current-plot-pen "average-honesty"
  plot mean.honesty
end

@#$#@#$#@
GRAPHICS-WINDOW
639
15
1117
514
-1
-1
14.63
1
10
1
1
1
0
1
1
1
0
31
0
31
0
0
1
ticks
30.0

BUTTON
226
24
317
84
Go
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
100
23
191
83
Setup
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
99
88
317
121
num-farmer
num-farmer
10
100
80
1
1
NIL
HORIZONTAL

SLIDER
354
88
572
121
num-seller
num-seller
1
10
7
1
1
NIL
HORIZONTAL

SLIDER
99
128
317
161
fine-farmer
fine-farmer
0
2
0.85
0.05
1
NIL
HORIZONTAL

SLIDER
354
128
572
161
fine-seller
fine-seller
0
10
1.2
0.1
1
NIL
HORIZONTAL

SLIDER
99
167
317
200
fine-deposit
fine-deposit
0
2
0.55
0.05
1
NIL
HORIZONTAL

SLIDER
354
167
572
200
inspect-rate.f
inspect-rate.f
0.01
1
0.31
0.1
1
NIL
HORIZONTAL

SLIDER
99
207
317
240
inspect-rate.s
inspect-rate.s
0.1
1
0.1
0.1
1
NIL
HORIZONTAL

SLIDER
354
206
572
239
num-inspect-veg
num-inspect-veg
0
100
28
1
1
NIL
HORIZONTAL

SLIDER
99
248
317
281
lambda
lambda
0
1
0.7
0.1
1
NIL
HORIZONTAL

PLOT
98
361
317
508
Qualified Rate
time
rate
0.0
10.0
0.0
1.0
true
false
"" ""
PENS
"qualified-rate" 1.0 0 -2674135 true "" ""

SWITCH
354
247
572
280
contractual?
contractual?
0
1
-1000

MONITOR
99
290
317
355
Qualified Rate
[qualification.r.g] of one-of govs
3
1
16

PLOT
353
361
572
507
Average Honesty
time
value
0.0
10.0
0.0
1.0
true
false
"" ""
PENS
"average-honesty" 1.0 0 -13345367 true "" ""

MONITOR
354
22
572
83
Contract Production Ratio
ratio.c.p
2
1
15

MONITOR
353
289
572
354
Average Honesty
mean.honesty
3
1
16

@#$#@#$#@
## WHAT IS IT?

(a general understanding of what the model is trying to show or explain)

## HOW IT WORKS

(what rules the agents use to create the overall behavior of the model)

## HOW TO USE IT

(how to use the model, including a description of each of the items in the Interface tab)

## THINGS TO NOTICE

(suggested things for the user to notice while running the model)

## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

(models in the NetLogo Models Library and elsewhere which are of related interest)

## CREDITS AND REFERENCES

(a reference to the model's URL on the web if it has one, as well as any other necessary credits, citations, and links)
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

person farmer
false
0
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Polygon -1 true false 60 195 90 210 114 154 120 195 180 195 187 157 210 210 240 195 195 90 165 90 150 105 150 150 135 90 105 90
Circle -7500403 true true 110 5 80
Rectangle -7500403 true true 127 79 172 94
Polygon -13345367 true false 120 90 120 180 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 180 90 172 89 165 135 135 135 127 90
Polygon -6459832 true false 116 4 113 21 71 33 71 40 109 48 117 34 144 27 180 26 188 36 224 23 222 14 178 16 167 0
Line -16777216 false 225 90 270 90
Line -16777216 false 225 15 225 90
Line -16777216 false 270 15 270 90
Line -16777216 false 247 15 247 90
Rectangle -6459832 true false 240 90 255 300

person police
false
0
Polygon -1 true false 124 91 150 165 178 91
Polygon -13345367 true false 134 91 149 106 134 181 149 196 164 181 149 106 164 91
Polygon -13345367 true false 180 195 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285
Polygon -13345367 true false 120 90 105 90 60 195 90 210 116 158 120 195 180 195 184 158 210 210 240 195 195 90 180 90 165 105 150 165 135 105 120 90
Rectangle -7500403 true true 123 76 176 92
Circle -7500403 true true 110 5 80
Polygon -13345367 true false 150 26 110 41 97 29 137 -1 158 6 185 0 201 6 196 23 204 34 180 33
Line -13345367 false 121 90 194 90
Line -16777216 false 148 143 150 196
Rectangle -16777216 true false 116 186 182 198
Rectangle -16777216 true false 109 183 124 227
Rectangle -16777216 true false 176 183 195 205
Circle -1 true false 152 143 9
Circle -1 true false 152 166 9
Polygon -1184463 true false 172 112 191 112 185 133 179 133
Polygon -1184463 true false 175 6 194 6 189 21 180 21
Line -1184463 false 149 24 197 24
Rectangle -16777216 true false 101 177 122 187
Rectangle -16777216 true false 179 164 183 186

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
0
Rectangle -7500403 true true 151 225 180 285
Rectangle -7500403 true true 47 225 75 285
Rectangle -7500403 true true 15 75 210 225
Circle -7500403 true true 135 75 150
Circle -16777216 true false 165 76 116

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

van side
false
0
Polygon -7500403 true true 26 147 18 125 36 61 161 61 177 67 195 90 242 97 262 110 273 129 260 149
Circle -16777216 true false 43 123 42
Circle -16777216 true false 194 124 42
Polygon -16777216 true false 45 68 37 95 183 96 169 69
Line -7500403 true 62 65 62 103
Line -7500403 true 115 68 120 100
Polygon -1 true false 271 127 258 126 257 114 261 109
Rectangle -16777216 true false 19 131 27 142

van top
true
0
Polygon -7500403 true true 90 117 71 134 228 133 210 117
Polygon -7500403 true true 150 8 118 10 96 17 85 30 84 264 89 282 105 293 149 294 192 293 209 282 215 265 214 31 201 17 179 10
Polygon -16777216 true false 94 129 105 120 195 120 204 128 180 150 120 150
Polygon -16777216 true false 90 270 105 255 105 150 90 135
Polygon -16777216 true false 101 279 120 286 180 286 198 281 195 270 105 270
Polygon -16777216 true false 210 270 195 255 195 150 210 135
Polygon -1 true false 201 16 201 26 179 20 179 10
Polygon -1 true false 99 16 99 26 121 20 121 10
Line -16777216 false 130 14 168 14
Line -16777216 false 130 18 168 18
Line -16777216 false 130 11 168 11
Line -16777216 false 185 29 194 112
Line -16777216 false 115 29 106 112
Line -7500403 false 210 180 195 180
Line -7500403 false 195 225 210 240
Line -7500403 false 105 225 90 240
Line -7500403 false 90 180 105 180

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.2.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="experiment" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="fine-deposit">
      <value value="0.55"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-inspect-veg">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-farmer">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="lambda">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="inspect-rate.s">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fine-seller">
      <value value="1.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fine-farmer">
      <value value="0.85"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="inspect-rate.f">
      <value value="0.51"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-seller">
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="contractual?">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
